import React, { Fragment, useState } from "react";
import { noop, enterKeyPressed } from "../../utils";
import "./TagList.css";

export default function TagList({
    canEdit = false,
    tags = [],
    onTagUpdate = noop
}) {
    const getTags = () => tags.join(",");
    const [editMode, setEditMode] = useState(false);
    const [editTags, setEditTags] = useState(getTags());

    const toggleEditMode = () => {
        if (editMode && canEdit) {
            onTagUpdate(editTags.split(",").map(x => x.trim()));
        }
        setEditMode(!editMode && canEdit);
    };

    const updateTags = ({ target }) => setEditTags(target.value);

    return (
        <span className="TagList" onDoubleClick={toggleEditMode}>
            {editMode && canEdit ? (
                <input
                    type="text"
                    style={{ width: `${editTags.length - 2}ch` }}
                    defaultValue={getTags()}
                    onChange={updateTags}
                    onKeyPress={enterKeyPressed(toggleEditMode)}
                    onBlur={() => editMode && toggleEditMode()}
                />
            ) : (
                <Fragment>
                    {tags.length <= 0 && <span>Add a Tag</span>}
                    <ul>
                        {tags.map(t => (
                            <li key={t}>{t}</li>
                        ))}
                    </ul>
                </Fragment>
            )}
        </span>
    );
}
