const { contextBridge, ipcRenderer } = require("electron");

const validSendChannels = ["note_command", "element-clicked"];
const validReceiveChannels = ["note_response"];

const send = (channel, data) => {
    if (validSendChannels.includes(channel)) {
        ipcRenderer.send(channel, JSON.stringify(data));
        return Promise.resolve();
    }
    return Promise.reject();
};

const receive = channel => {
    if (validReceiveChannels.includes(channel)) {
        return new Promise(resolve => {
            ipcRenderer.on(channel, (_, ...args) => resolve(...args));
        });
    }
    return Promise.reject();
};

const receiveOnce = channel => {
    if (validReceiveChannels.includes(channel)) {
        return new Promise(resolve => {
            ipcRenderer.once(channel, (_, ...args) => resolve(...args));
        });
    }
    return Promise.reject();
};

contextBridge.exposeInMainWorld("api", {
    send,
    receive,
    receiveOnce,
    sendLinkNav: target => ipcRenderer.send("element-clicked", target),
    sendAction: async ({ type, payload }) => async dispatch => {
        if (!type || type === "") {
            throw new Error("type cannot be null or empty");
        }

        await send(type, JSON.stringify(payload));
    },
    expectAction: ({ type }, dispatch) => {
        if (!type || type === "") {
            throw new Error("type cannot be null or empty");
        }
    },
    getSettings: async () => {
        send("note_command", { type: "getSettings" });
        const response = await receiveOnce("note_response");
        return JSON.parse(response);
    },
    loadNotes: async () => {
        send("note_command", { type: "getNotes" });
        const response = await receiveOnce("note_response");
        return JSON.parse(response);
    },
    saveNote: async ({ title, content, tags }) => {
        send("note_command", {
            type: "saveNote",
            payload: { title, content, tags }
        });
        const response = await receiveOnce("note_response");
        return JSON.parse(response);
    }
});
