import {
    loadNotes as loadNotesBackend,
    updateNote as updateNoteBackend,
    deleteNote as deleteNoteBackend
} from "./api";

const SELECT_NOTE = "SELECT_NOTE";
const LOAD_NOTES_START = "LOAD_NOTES_START";
const LOAD_NOTES_SUCCESS = "LOAD_NOTES_SUCCESS";
const OPERATION_FAIL = "OPERATION_FAIL";

const UPDATE_NOTE_START = "UPDATE_NOTE_START";
const UPDATE_NOTE_SUCCESS = "UPDATE_NOTE_SUCCESS";

const CREATE_NOTE_START = "CREATE_NOTE_START";
const CREATE_NOTE_SUCCESS = "CREATE_NOTE_SUCCESS";

const DELETE_NOTE_START = "DELETE_NOTE_START";
const DELETE_NOTE_SUCCESS = "DELETE_NOTE_SUCCESS";

const initialState = {
    notes: [],
    selectedNoteId: null,
    error: null
};

export const reducer = (cs = initialState, { type, payload }) => {
    switch (type) {
        case SELECT_NOTE:
        case UPDATE_NOTE_SUCCESS:
        case CREATE_NOTE_SUCCESS:
            return { ...cs, selectedNote: payload };
        case LOAD_NOTES_SUCCESS:
            return { ...cs, notes: payload };
        case OPERATION_FAIL:
            return { ...cs, error: payload };
        case DELETE_NOTE_SUCCESS:
        default:
            return { ...cs };
    }
};

const updateNote = ({ title, tags = [], content = "" }) => async (
    dispatch,
    getState
) => {
    try {
        if (title === "" || !title) {
            throw new Error("title cannot be null or empty");
        }
        const {
            notes: { selectedNote }
        } = getState();
        const { payload } = await updateNoteBackend({ title, tags, content });
        console.log(`save note result: `, payload);
        dispatch({
            type: UPDATE_NOTE_SUCCESS,
            payload: { ...selectedNote, ...payload, content }
        });
    } catch (error) {
        dispatch({ type: OPERATION_FAIL, payload: error });
    }
};

const createNote = ({ title }) => async (dispatch, getState) => {
    try {
        if (title === "" || !title) {
            throw new Error("title cannot be null or empty");
        }
        const result = await updateNoteBackend({ title });
        dispatch({ type: CREATE_NOTE_SUCCESS, payload: result });
    } catch (error) {
        dispatch({ type: OPERATION_FAIL, payload: error });
    }
};

const selectNote = ({ title }) => (dispatch, getState) => {
    const normalizedTitle = title.toLocaleLowerCase();
    const { selectedNote, notes } = getState().notes;

    let foundNote = selectedNote;
    const notesFilter = notes.filter(
        n => n.title.toLocaleLowerCase() === normalizedTitle
    );

    if (notesFilter.length > 0) {
        foundNote = notesFilter[0];
        dispatch({
            type: "SELECT_NOTE",
            payload: { ...foundNote }
        });
    }
};

const deleteNote = ({ title }) => async (dispatch, getState) => {
    try {
        if (!title || title === "") {
            throw new Error("title cannot be null or empty");
        }
        const result = await deleteNoteBackend({ title });
        dispatch({ type: DELETE_NOTE_SUCCESS, payload: result });
    } catch (error) {
        dispatch({ type: OPERATION_FAIL, payload: error });
    }
};

const loadNotes = () => async (dispatch, getState) => {
    const { notesLoading } = getState().notes;
    if (notesLoading) {
        console.warn(
            "trying to load notes when the operation has already begun."
        );
        return;
    }

    try {
        const { payload } = await loadNotesBackend();
        dispatch({ type: LOAD_NOTES_SUCCESS, payload: payload.notes || [] });
    } catch (error) {
        throw error;
        dispatch({ type: OPERATION_FAIL, payload: { error } });
    }
};

export const actions = {
    loadNotes,
    selectNote,
    deleteNote,
    createNote,
    updateNote
};
